@@ -29,9 +29,13 @@ mod linux;
 mod windows;
 
 pub mod app;
+pub mod headers;
 mod settings;
 mod warp_server;
 
+// TODO on_msg_from_javascript
+// TODO inject javascript on load
+
 // TODO GTK: glade: connect headerbar
 // TODO GTK: Mainwindow (HeaderBar -> hello_header example, Subclass MainWindow with new)
 // TODO Inject global.js, Messages to and from the webview
